@@ -74,7 +74,6 @@ void JuliaSession::login()
         return;
     }
 
-
     m_process->waitForReadyRead();
     QTextStream stream(m_process->readAllStandardOutput());
 
@@ -129,6 +128,14 @@ void JuliaSession::login()
         return;
     }
 
+    // set the current working directory to the project directory
+    const auto& path = worksheetPath();
+    if (!path.isEmpty())
+    {
+        const auto& dir = QFileInfo(path).absoluteDir().absolutePath();
+        runJuliaCommand(QLatin1String("cd(\"") + dir + QLatin1String("\")"));
+    }
+
     static_cast<JuliaVariableModel*>(variableModel())->setJuliaServer(m_interface);
 
     std::random_device rd;
