@@ -43,6 +43,8 @@
 #include "backendchoosedialog.h"
 #include <QMetaObject>
 
+using namespace Qt::Literals::StringLiterals;
+
 CantorShell::CantorShell() : KParts::MainWindow(), m_tabWidget(new QTabWidget(this))
 {
     // set the shell's ui resource file
@@ -154,7 +156,7 @@ void CantorShell::setupActions()
 
     QAction* toPreviousTab = new QAction(i18n("Go to previous worksheet"), actionCollection());
     actionCollection()->addAction(QLatin1String("go_to_previous_tab"), toPreviousTab);
-    actionCollection()->setDefaultShortcut(toPreviousTab, Qt::CTRL+Qt::Key_PageDown);
+    actionCollection()->setDefaultShortcut(toPreviousTab, Qt::CTRL | Qt::Key_PageDown);
     connect(toPreviousTab, &QAction::triggered, toPreviousTab, [this](){
         const int index = m_tabWidget->currentIndex()-1;
         if (index >= 0)
@@ -166,7 +168,7 @@ void CantorShell::setupActions()
 
     QAction* toNextTab = new QAction(i18n("Go to next worksheet"), actionCollection());
     actionCollection()->addAction(QLatin1String("go_to_next_tab"), toNextTab);
-    actionCollection()->setDefaultShortcut(toNextTab, Qt::CTRL+Qt::Key_PageUp);
+    actionCollection()->setDefaultShortcut(toNextTab, Qt::CTRL | Qt::Key_PageUp);
     connect(toNextTab, &QAction::triggered, toNextTab, [this](){
         const int index = m_tabWidget->currentIndex()+1;
         if (index < m_tabWidget->count())
@@ -325,7 +327,7 @@ void CantorShell::addWorksheet(const QString& backendName)
     // name which is a bad idea usually.. but it's alright in this
     // case since our Part is made for this Shell
 
-    const auto partResult = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf5/parts/cantorpart")), m_tabWidget, {backendName});
+    const auto partResult = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf6/parts/cantorpart")), m_tabWidget, {backendName});
 
     if (partResult)
     {
@@ -381,7 +383,7 @@ void CantorShell::addWorksheet(const QString& backendName)
 
         //all panels initialized, show the default help string in the help panel
         if (backend)
-            emit showHelp(backend->defaultHelp());
+            Q_EMIT showHelp(backend->defaultHelp());
     }
     else
     {
@@ -577,13 +579,16 @@ bool CantorShell::reallyClose(bool checkAllParts) {
             }
         }
         if(!modified) return true;
-        int want_save = KMessageBox::warningYesNo( this,
+        int want_save = KMessageBox::warningTwoActions( this,
             i18n("Multiple unsaved Worksheets are opened. Do you want to close them?"),
-            i18n("Close Cantor"));
+            i18n("Close Cantor"),
+            KStandardGuiItem::close(),
+            KStandardGuiItem::cancel()
+        );
         switch (want_save) {
-            case KMessageBox::Yes:
+            case KMessageBox::PrimaryAction:
                 return true;
-            case KMessageBox::No:
+            case KMessageBox::SecondaryAction:
                 return false;
         }
     }
@@ -594,11 +599,14 @@ bool CantorShell::reallyClose(bool checkAllParts) {
 bool CantorShell::reallyCloseThisPart(KParts::ReadWritePart* part)
 {
      if (part && part->isModified() ) {
-        int want_save = KMessageBox::warningYesNoCancel( this,
+        const int want_save = KMessageBox::warningTwoActionsCancel(this,
             i18n("The current project has been modified. Do you want to save it?"),
-            i18n("Save Project"));
+            i18n("Save Project"),
+            KStandardGuiItem::save(),
+            KStandardGuiItem::dontSave()
+        );
         switch (want_save) {
-            case KMessageBox::Yes:
+            case KMessageBox::PrimaryAction:
                 part->save();
                 if(part->waitSaveComplete()) {
                     return true;
@@ -608,7 +616,7 @@ bool CantorShell::reallyCloseThisPart(KParts::ReadWritePart* part)
                 }
             case KMessageBox::Cancel:
                 return false;
-            case KMessageBox::No:
+            case KMessageBox::SecondaryAction:
                 return true;
         }
     }
@@ -630,6 +638,8 @@ void CantorShell::closeEvent(QCloseEvent* event) {
 void CantorShell::showSettings()
 {
     KConfigDialog *dialog = new KConfigDialog(this,  QLatin1String("settings"), Settings::self());
+    dialog->setFaceType(KPageDialog::FlatList);
+    dialog->resize(1000, 700);
 
     QWidget *generalSettings = new QWidget;
     Ui::SettingsBase base;
@@ -913,7 +923,7 @@ void CantorShell::updateBackendForPart(const QString& backendName)
         if (backend)
         {
             //show the default help string in the help panel
-            emit showHelp(backend->defaultHelp());
+            Q_EMIT showHelp(backend->defaultHelp());
         }
     }
 }
